'use strict';
/**
 * 2011 Peter 'Pita' Martischka
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS-IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

const pg = require('pg');
const postgresCommon = require('./postgres_common');

exports.Database = function (settings) {
  this.settings = settings;

  this.settings.cache = settings.cache || 1000;
  this.settings.writeInterval = 100;
  this.settings.json = true;

  this.db = new pg.Client(this.settings);
  this.db.connect();
};

exports.Database.prototype.init = postgresCommon.init;
exports.Database.prototype.get = postgresCommon.get;
exports.Database.prototype.findKeys = postgresCommon.findKeys;
exports.Database.prototype.set = postgresCommon.set;
exports.Database.prototype.remove = postgresCommon.remove;
exports.Database.prototype.doBulk = postgresCommon.doBulk;
exports.Database.prototype.close = postgresCommon.close;
